@@ -11,7 +11,7 @@ from path import Directory, ProjectDirectory
 from generator import Site
 
 
-__version__ = "0.0.5"
+__version__ = "0.0.6"
 
 
 def console():
@@ -71,7 +71,8 @@ def console():
         d = Directory(project_dir, '.git')
         if d.exists():
             try:
-                output = subprocess.check_output(["git", "pull", "origin", "master"], stderr=subprocess.STDOUT)
+                git_path = subprocess.check_output(['which', 'git']).strip()
+                output = subprocess.check_output([git_path, "pull", "origin", "master"], stderr=subprocess.STDOUT)
                 if (output.find("Updating") >= 0) or not output_dir.exists():
                     # there are new changes, let's recompile the project
                     s = Site(project_dir, output_dir)
